.. include:: ../../README.rst

.. toctree::
   :caption: Welcome
   :maxdepth: 1

   install/gettingstarted
   install/core
   install/database
..    contributors

.. toctree::
   :caption: User Guide
   :maxdepth: 1

   user/overview
   user/script
   user/api
   user/algorithms
   user/searchspace
   user/monitoring
   user/evc
   user/storage
   user/config
   user/parallel

.. toctree::
   :caption: Tutorials
   :maxdepth: 1

   tutorials/scikit-learn
   tutorials/pytorch-mnist
   tutorials/cluster
   tutorials/pytorch_cifar
   tutorials/pytorch_a2c_ppo

.. toctree::
   :caption: Plugins
   :maxdepth: 1

   plugins/base
   plugins/install
   plugins/algorithms

.. toctree::
   :caption: Developer Guide
   :maxdepth: 1

   developer/overview
   developer/installing
   developer/standards
   developer/testing
   developer/documenting
   developer/ci
   developer/release

.. toctree::
   :maxdepth: 2
   :caption: Code Reference

   code/algo
   code/client
   code/core
   code/plotting
   code/storage

.. Don't fetch reference/viz
